import QtQuick 2.0
import MuseScore 3.0

MuseScore {
    menuPath: "Plugins.C_25_key_diatonic accordion_4"
    property var fingerings : [
    "c", "C", "d", "D", "e", "f", "F", "g", "G", "a", "A", "b",
    "c", "C", "d", "D", "e", "f", "F", "g", "G", "a", "A", "b",
    "c", "C", "d", "D", "e", "f", "F", "g", "G", "a", "A", "b",
    "c", "C", "d", "D", "e", "f", "F", "g", "G", "a", "A", "b"
    ]

    // Which button to show. If two buttons possible, put \n between entries
    property var button :  [
    " ", " ", " \n2\n \n1\n ", " ", " \n1'", " ", " \n \n \n2\n ", " \n3\n2'\n1'\n ", " ", " \n \n \n3\n ", " ", " \n4\n \n2'\n ",
    " \n3'\n \n4\n ", " \n \n \n1''\n ", " \n5\n \n3'\n ", " \n1''", " \n4'\n \n5\n ", " \n \n \n4'\n", " \n \n \n6\n ", " \n6\n5'", " \n2''", " \n \n \n7\n5'", " \n \n \n2''\n ", " \n7\n \n6'\n ",
    " \n6'\n \n8\n ", " \n \n \n3''\n ", " \n8\n \n7'\n ", " \n3''", " \n7'\n \n9\n ", " \n \n \n8'\n ", " \n \n \n10\n ", " \n8'\n9\n ", " \n4''", " \n \n \n9'\n11", " \n \n \n4''\n ", " \n10\n \n10'\n ",
    " \n9'", " ", " \n11", " ", " \n10'", " ", " ", " ", " ", " ", " ", " "
    ]

    function addButton(cursor, note) {
        var pitch = note.pitch
        var index = pitch - 48
        if (index >= 0 && index < button.length) {
            var text = newElement(Element.STAFF_TEXT)
            text.text = button[index]
            text.autoplace = false
            text.offsetY = 10
            cursor.add(text)
        }
    }
    onRun: {
        if (typeof curScore === 'undefined')
            Qt.quit()
        var cursor = curScore.newCursor()
        var startStaff
        var endStaff
        var endTick
        var fullScore = false
        cursor.rewind(1)
        if (!cursor.segment) {
            // no selection
            fullScore = true
            startStaff = 0 // start with 1st staff
            endStaff = curScore.nstaves - 1 // and end with last
        } else {
            startStaff = cursor.staffIdx
            cursor.rewind(2)
            if (cursor.tick == 0) {
                // this happens when the selection includes
                // the last measure of the score.
                // rewind(2) goes behind the last segment (where
                // there's none) and sets tick=0
                endTick = curScore.lastSegment.tick + 1
            } else {
                endTick = cursor.tick
            }
            endStaff = cursor.staffIdx
        }
        console.log(startStaff + " - " + endStaff + " - " + endTick)

        for (var staff = startStaff; staff <= endStaff; staff++) {
            for (var voice = 0; voice < 4; voice++) {
                cursor.rewind(1) // beginning of selection
                cursor.voice = voice
                cursor.staffIdx = staff

                if (fullScore)
                    // no selection
                    cursor.rewind(0) // beginning of score

                while (cursor.segment && (fullScore || cursor.tick < endTick)) {
                    if (cursor.element && cursor.element.type == Element.CHORD) {
                        var graceChords = cursor.element.graceNotes
                        for (var i = 0; i < graceChords.length; i++) {
                            // iterate through all grace chords
                            var notes = graceChords[i].notes
                            addButton(cursor, notes[0])
                        }
                        var notes = cursor.element.notes
                        addButton(cursor, notes[0])
                    } // end if CHORD
                    cursor.next()
                } // end while segment
            } // end for voice
        } // end for staff
        Qt.quit()
    }
}
